# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
from .. import _utilities
import typing
# Export this package's modules as members:
from .flavor_v2 import *
from .flavorprofile_v2 import *
from .get_flavor_v2 import *
from .get_flavorprofile_v2 import *
from .get_lb_flavor_deprecated import *
from .get_listener_v2 import *
from .get_loadbalancer_v2 import *
from .get_pool_v2 import *
from .l7_policy_v2 import *
from .l7_rule_v2 import *
from .listener import *
from .load_balancer import *
from .member import *
from .members import *
from .monitor import *
from .pool import *
from .quota import *
from ._inputs import *
from . import outputs



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['BgpvpnV2Args', 'BgpvpnV2']

@pulumi.input_type
class BgpvpnV2Args:
    def __init__(__self__, *,
                 export_targets: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 import_targets: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 local_pref: Optional[pulumi.Input[_builtins.int]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 route_distinguishers: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 route_targets: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None,
                 vni: Optional[pulumi.Input[_builtins.int]] = None):
        """
        The set of arguments for constructing a BgpvpnV2 resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] export_targets: A list of additional Route Targets that will be
               used for export.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] import_targets: A list of additional Route Targets that will be
               imported.
        :param pulumi.Input[_builtins.int] local_pref: The default BGP LOCAL\\_PREF of routes that will be
               advertised to the BGP VPN, unless overridden per-route.
        :param pulumi.Input[_builtins.str] name: The name of the BGP VPN. Changing this updates the name of
               the existing BGP VPN.
        :param pulumi.Input[_builtins.str] project_id: The ID of the project that owns the BGPVPN. Only
               administrative and users with `advsvc` role can specify a project ID other
               than their own. Changing this creates a new BGP VPN.
        :param pulumi.Input[_builtins.str] region: The region in which to obtain the V2 Networking client.
               A Networking client is needed to create a BGP VPN service. If omitted, the
               `region` argument of the provider is used. Changing this creates a new
               BGP VPN.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] route_distinguishers: A list of route distinguisher strings. If
               specified, one of these RDs will be used to advertise VPN routes.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] route_targets: A list of Route Targets that will be both
               imported and used for export.
        :param pulumi.Input[_builtins.str] type: The type of the BGP VPN (either `l2` or `l3`). Changing this
               creates a new BGP VPN. Defaults to `l3`.
        :param pulumi.Input[_builtins.int] vni: The globally-assigned VXLAN VNI for the BGP VPN. Changing
               this creates a new BGP VPN.
        """
        if export_targets is not None:
            pulumi.set(__self__, "export_targets", export_targets)
        if import_targets is not None:
            pulumi.set(__self__, "import_targets", import_targets)
        if local_pref is not None:
            pulumi.set(__self__, "local_pref", local_pref)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if route_distinguishers is not None:
            pulumi.set(__self__, "route_distinguishers", route_distinguishers)
        if route_targets is not None:
            pulumi.set(__self__, "route_targets", route_targets)
        if type is not None:
            pulumi.set(__self__, "type", type)
        if vni is not None:
            pulumi.set(__self__, "vni", vni)

    @_builtins.property
    @pulumi.getter(name="exportTargets")
    def export_targets(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        A list of additional Route Targets that will be
        used for export.
        """
        return pulumi.get(self, "export_targets")

    @export_targets.setter
    def export_targets(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "export_targets", value)

    @_builtins.property
    @pulumi.getter(name="importTargets")
    def import_targets(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        A list of additional Route Targets that will be
        imported.
        """
        return pulumi.get(self, "import_targets")

    @import_targets.setter
    def import_targets(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "import_targets", value)

    @_builtins.property
    @pulumi.getter(name="localPref")
    def local_pref(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The default BGP LOCAL\\_PREF of routes that will be
        advertised to the BGP VPN, unless overridden per-route.
        """
        return pulumi.get(self, "local_pref")

    @local_pref.setter
    def local_pref(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "local_pref", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the BGP VPN. Changing this updates the name of
        the existing BGP VPN.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the project that owns the BGPVPN. Only
        administrative and users with `advsvc` role can specify a project ID other
        than their own. Changing this creates a new BGP VPN.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The region in which to obtain the V2 Networking client.
        A Networking client is needed to create a BGP VPN service. If omitted, the
        `region` argument of the provider is used. Changing this creates a new
        BGP VPN.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter(name="routeDistinguishers")
    def route_distinguishers(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        A list of route distinguisher strings. If
        specified, one of these RDs will be used to advertise VPN routes.
        """
        return pulumi.get(self, "route_distinguishers")

    @route_distinguishers.setter
    def route_distinguishers(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "route_distinguishers", value)

    @_builtins.property
    @pulumi.getter(name="routeTargets")
    def route_targets(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        A list of Route Targets that will be both
        imported and used for export.
        """
        return pulumi.get(self, "route_targets")

    @route_targets.setter
    def route_targets(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "route_targets", value)

    @_builtins.property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The type of the BGP VPN (either `l2` or `l3`). Changing this
        creates a new BGP VPN. Defaults to `l3`.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "type", value)

    @_builtins.property
    @pulumi.getter
    def vni(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The globally-assigned VXLAN VNI for the BGP VPN. Changing
        this creates a new BGP VPN.
        """
        return pulumi.get(self, "vni")

    @vni.setter
    def vni(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "vni", value)


@pulumi.input_type
class _BgpvpnV2State:
    def __init__(__self__, *,
                 export_targets: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 import_targets: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 local_pref: Optional[pulumi.Input[_builtins.int]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 networks: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 ports: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 route_distinguishers: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 route_targets: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 routers: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 shared: Optional[pulumi.Input[_builtins.bool]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None,
                 vni: Optional[pulumi.Input[_builtins.int]] = None):
        """
        Input properties used for looking up and filtering BgpvpnV2 resources.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] export_targets: A list of additional Route Targets that will be
               used for export.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] import_targets: A list of additional Route Targets that will be
               imported.
        :param pulumi.Input[_builtins.int] local_pref: The default BGP LOCAL\\_PREF of routes that will be
               advertised to the BGP VPN, unless overridden per-route.
        :param pulumi.Input[_builtins.str] name: The name of the BGP VPN. Changing this updates the name of
               the existing BGP VPN.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] networks: A list of network IDs that are associated with the BGP VPN.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] ports: A list of port IDs that are associated with the BGP VPN.
        :param pulumi.Input[_builtins.str] project_id: The ID of the project that owns the BGPVPN. Only
               administrative and users with `advsvc` role can specify a project ID other
               than their own. Changing this creates a new BGP VPN.
        :param pulumi.Input[_builtins.str] region: The region in which to obtain the V2 Networking client.
               A Networking client is needed to create a BGP VPN service. If omitted, the
               `region` argument of the provider is used. Changing this creates a new
               BGP VPN.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] route_distinguishers: A list of route distinguisher strings. If
               specified, one of these RDs will be used to advertise VPN routes.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] route_targets: A list of Route Targets that will be both
               imported and used for export.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] routers: A list of router IDs that are associated with the BGP VPN.
        :param pulumi.Input[_builtins.bool] shared: Indicates whether the BGP VPN is shared across projects.
        :param pulumi.Input[_builtins.str] type: The type of the BGP VPN (either `l2` or `l3`). Changing this
               creates a new BGP VPN. Defaults to `l3`.
        :param pulumi.Input[_builtins.int] vni: The globally-assigned VXLAN VNI for the BGP VPN. Changing
               this creates a new BGP VPN.
        """
        if export_targets is not None:
            pulumi.set(__self__, "export_targets", export_targets)
        if import_targets is not None:
            pulumi.set(__self__, "import_targets", import_targets)
        if local_pref is not None:
            pulumi.set(__self__, "local_pref", local_pref)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if networks is not None:
            pulumi.set(__self__, "networks", networks)
        if ports is not None:
            pulumi.set(__self__, "ports", ports)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if route_distinguishers is not None:
            pulumi.set(__self__, "route_distinguishers", route_distinguishers)
        if route_targets is not None:
            pulumi.set(__self__, "route_targets", route_targets)
        if routers is not None:
            pulumi.set(__self__, "routers", routers)
        if shared is not None:
            pulumi.set(__self__, "shared", shared)
        if type is not None:
            pulumi.set(__self__, "type", type)
        if vni is not None:
            pulumi.set(__self__, "vni", vni)

    @_builtins.property
    @pulumi.getter(name="exportTargets")
    def export_targets(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        A list of additional Route Targets that will be
        used for export.
        """
        return pulumi.get(self, "export_targets")

    @export_targets.setter
    def export_targets(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "export_targets", value)

    @_builtins.property
    @pulumi.getter(name="importTargets")
    def import_targets(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        A list of additional Route Targets that will be
        imported.
        """
        return pulumi.get(self, "import_targets")

    @import_targets.setter
    def import_targets(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "import_targets", value)

    @_builtins.property
    @pulumi.getter(name="localPref")
    def local_pref(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The default BGP LOCAL\\_PREF of routes that will be
        advertised to the BGP VPN, unless overridden per-route.
        """
        return pulumi.get(self, "local_pref")

    @local_pref.setter
    def local_pref(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "local_pref", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the BGP VPN. Changing this updates the name of
        the existing BGP VPN.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def networks(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        A list of network IDs that are associated with the BGP VPN.
        """
        return pulumi.get(self, "networks")

    @networks.setter
    def networks(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "networks", value)

    @_builtins.property
    @pulumi.getter
    def ports(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        A list of port IDs that are associated with the BGP VPN.
        """
        return pulumi.get(self, "ports")

    @ports.setter
    def ports(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "ports", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the project that owns the BGPVPN. Only
        administrative and users with `advsvc` role can specify a project ID other
        than their own. Changing this creates a new BGP VPN.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The region in which to obtain the V2 Networking client.
        A Networking client is needed to create a BGP VPN service. If omitted, the
        `region` argument of the provider is used. Changing this creates a new
        BGP VPN.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter(name="routeDistinguishers")
    def route_distinguishers(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        A list of route distinguisher strings. If
        specified, one of these RDs will be used to advertise VPN routes.
        """
        return pulumi.get(self, "route_distinguishers")

    @route_distinguishers.setter
    def route_distinguishers(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "route_distinguishers", value)

    @_builtins.property
    @pulumi.getter(name="routeTargets")
    def route_targets(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        A list of Route Targets that will be both
        imported and used for export.
        """
        return pulumi.get(self, "route_targets")

    @route_targets.setter
    def route_targets(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "route_targets", value)

    @_builtins.property
    @pulumi.getter
    def routers(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        A list of router IDs that are associated with the BGP VPN.
        """
        return pulumi.get(self, "routers")

    @routers.setter
    def routers(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "routers", value)

    @_builtins.property
    @pulumi.getter
    def shared(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Indicates whether the BGP VPN is shared across projects.
        """
        return pulumi.get(self, "shared")

    @shared.setter
    def shared(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "shared", value)

    @_builtins.property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The type of the BGP VPN (either `l2` or `l3`). Changing this
        creates a new BGP VPN. Defaults to `l3`.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "type", value)

    @_builtins.property
    @pulumi.getter
    def vni(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The globally-assigned VXLAN VNI for the BGP VPN. Changing
        this creates a new BGP VPN.
        """
        return pulumi.get(self, "vni")

    @vni.setter
    def vni(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "vni", value)


warnings.warn("""openstack.index/bgpvpnv2.BgpvpnV2 has been deprecated in favor of openstack.bgpvpn/v2.V2""", DeprecationWarning)


@pulumi.type_token("openstack:index/bgpvpnV2:BgpvpnV2")
class BgpvpnV2(pulumi.CustomResource):
    warnings.warn("""openstack.index/bgpvpnv2.BgpvpnV2 has been deprecated in favor of openstack.bgpvpn/v2.V2""", DeprecationWarning)

    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 export_targets: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 import_targets: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 local_pref: Optional[pulumi.Input[_builtins.int]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 route_distinguishers: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 route_targets: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None,
                 vni: Optional[pulumi.Input[_builtins.int]] = None,
                 __props__=None):
        """
        Manages a V2 BGP VPN service resource within OpenStack.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_openstack as openstack

        bgpvpn1 = openstack.bgpvpn.V2("bgpvpn_1",
            name="bgpvpn1",
            route_distinguishers=["64512:1"],
            route_targets=["64512:1"],
            import_targets=["64512:2"],
            export_targets=["64512:3"])
        ```

        ## Import

        BGP VPNs can be imported using the `id`, e.g.

        hcl

        ```sh
        $ pulumi import openstack:index/bgpvpnV2:BgpvpnV2 bgpvpn_1 1eec2c66-6be2-4305-af3f-354c9b81f18c
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] export_targets: A list of additional Route Targets that will be
               used for export.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] import_targets: A list of additional Route Targets that will be
               imported.
        :param pulumi.Input[_builtins.int] local_pref: The default BGP LOCAL\\_PREF of routes that will be
               advertised to the BGP VPN, unless overridden per-route.
        :param pulumi.Input[_builtins.str] name: The name of the BGP VPN. Changing this updates the name of
               the existing BGP VPN.
        :param pulumi.Input[_builtins.str] project_id: The ID of the project that owns the BGPVPN. Only
               administrative and users with `advsvc` role can specify a project ID other
               than their own. Changing this creates a new BGP VPN.
        :param pulumi.Input[_builtins.str] region: The region in which to obtain the V2 Networking client.
               A Networking client is needed to create a BGP VPN service. If omitted, the
               `region` argument of the provider is used. Changing this creates a new
               BGP VPN.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] route_distinguishers: A list of route distinguisher strings. If
               specified, one of these RDs will be used to advertise VPN routes.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] route_targets: A list of Route Targets that will be both
               imported and used for export.
        :param pulumi.Input[_builtins.str] type: The type of the BGP VPN (either `l2` or `l3`). Changing this
               creates a new BGP VPN. Defaults to `l3`.
        :param pulumi.Input[_builtins.int] vni: The globally-assigned VXLAN VNI for the BGP VPN. Changing
               this creates a new BGP VPN.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[BgpvpnV2Args] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages a V2 BGP VPN service resource within OpenStack.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_openstack as openstack

        bgpvpn1 = openstack.bgpvpn.V2("bgpvpn_1",
            name="bgpvpn1",
            route_distinguishers=["64512:1"],
            route_targets=["64512:1"],
            import_targets=["64512:2"],
            export_targets=["64512:3"])
        ```

        ## Import

        BGP VPNs can be imported using the `id`, e.g.

        hcl

        ```sh
        $ pulumi import openstack:index/bgpvpnV2:BgpvpnV2 bgpvpn_1 1eec2c66-6be2-4305-af3f-354c9b81f18c
        ```

        :param str resource_name: The name of the resource.
        :param BgpvpnV2Args args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(BgpvpnV2Args, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 export_targets: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 import_targets: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 local_pref: Optional[pulumi.Input[_builtins.int]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 route_distinguishers: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 route_targets: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None,
                 vni: Optional[pulumi.Input[_builtins.int]] = None,
                 __props__=None):
        pulumi.log.warn("""BgpvpnV2 is deprecated: openstack.index/bgpvpnv2.BgpvpnV2 has been deprecated in favor of openstack.bgpvpn/v2.V2""")
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = BgpvpnV2Args.__new__(BgpvpnV2Args)

            __props__.__dict__["export_targets"] = export_targets
            __props__.__dict__["import_targets"] = import_targets
            __props__.__dict__["local_pref"] = local_pref
            __props__.__dict__["name"] = name
            __props__.__dict__["project_id"] = project_id
            __props__.__dict__["region"] = region
            __props__.__dict__["route_distinguishers"] = route_distinguishers
            __props__.__dict__["route_targets"] = route_targets
            __props__.__dict__["type"] = type
            __props__.__dict__["vni"] = vni
            __props__.__dict__["networks"] = None
            __props__.__dict__["ports"] = None
            __props__.__dict__["routers"] = None
            __props__.__dict__["shared"] = None
        super(BgpvpnV2, __self__).__init__(
            'openstack:index/bgpvpnV2:BgpvpnV2',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            export_targets: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            import_targets: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            local_pref: Optional[pulumi.Input[_builtins.int]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            networks: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            ports: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            project_id: Optional[pulumi.Input[_builtins.str]] = None,
            region: Optional[pulumi.Input[_builtins.str]] = None,
            route_distinguishers: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            route_targets: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            routers: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            shared: Optional[pulumi.Input[_builtins.bool]] = None,
            type: Optional[pulumi.Input[_builtins.str]] = None,
            vni: Optional[pulumi.Input[_builtins.int]] = None) -> 'BgpvpnV2':
        """
        Get an existing BgpvpnV2 resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] export_targets: A list of additional Route Targets that will be
               used for export.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] import_targets: A list of additional Route Targets that will be
               imported.
        :param pulumi.Input[_builtins.int] local_pref: The default BGP LOCAL\\_PREF of routes that will be
               advertised to the BGP VPN, unless overridden per-route.
        :param pulumi.Input[_builtins.str] name: The name of the BGP VPN. Changing this updates the name of
               the existing BGP VPN.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] networks: A list of network IDs that are associated with the BGP VPN.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] ports: A list of port IDs that are associated with the BGP VPN.
        :param pulumi.Input[_builtins.str] project_id: The ID of the project that owns the BGPVPN. Only
               administrative and users with `advsvc` role can specify a project ID other
               than their own. Changing this creates a new BGP VPN.
        :param pulumi.Input[_builtins.str] region: The region in which to obtain the V2 Networking client.
               A Networking client is needed to create a BGP VPN service. If omitted, the
               `region` argument of the provider is used. Changing this creates a new
               BGP VPN.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] route_distinguishers: A list of route distinguisher strings. If
               specified, one of these RDs will be used to advertise VPN routes.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] route_targets: A list of Route Targets that will be both
               imported and used for export.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] routers: A list of router IDs that are associated with the BGP VPN.
        :param pulumi.Input[_builtins.bool] shared: Indicates whether the BGP VPN is shared across projects.
        :param pulumi.Input[_builtins.str] type: The type of the BGP VPN (either `l2` or `l3`). Changing this
               creates a new BGP VPN. Defaults to `l3`.
        :param pulumi.Input[_builtins.int] vni: The globally-assigned VXLAN VNI for the BGP VPN. Changing
               this creates a new BGP VPN.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _BgpvpnV2State.__new__(_BgpvpnV2State)

        __props__.__dict__["export_targets"] = export_targets
        __props__.__dict__["import_targets"] = import_targets
        __props__.__dict__["local_pref"] = local_pref
        __props__.__dict__["name"] = name
        __props__.__dict__["networks"] = networks
        __props__.__dict__["ports"] = ports
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["region"] = region
        __props__.__dict__["route_distinguishers"] = route_distinguishers
        __props__.__dict__["route_targets"] = route_targets
        __props__.__dict__["routers"] = routers
        __props__.__dict__["shared"] = shared
        __props__.__dict__["type"] = type
        __props__.__dict__["vni"] = vni
        return BgpvpnV2(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="exportTargets")
    def export_targets(self) -> pulumi.Output[Sequence[_builtins.str]]:
        """
        A list of additional Route Targets that will be
        used for export.
        """
        return pulumi.get(self, "export_targets")

    @_builtins.property
    @pulumi.getter(name="importTargets")
    def import_targets(self) -> pulumi.Output[Sequence[_builtins.str]]:
        """
        A list of additional Route Targets that will be
        imported.
        """
        return pulumi.get(self, "import_targets")

    @_builtins.property
    @pulumi.getter(name="localPref")
    def local_pref(self) -> pulumi.Output[Optional[_builtins.int]]:
        """
        The default BGP LOCAL\\_PREF of routes that will be
        advertised to the BGP VPN, unless overridden per-route.
        """
        return pulumi.get(self, "local_pref")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the BGP VPN. Changing this updates the name of
        the existing BGP VPN.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def networks(self) -> pulumi.Output[Sequence[_builtins.str]]:
        """
        A list of network IDs that are associated with the BGP VPN.
        """
        return pulumi.get(self, "networks")

    @_builtins.property
    @pulumi.getter
    def ports(self) -> pulumi.Output[Sequence[_builtins.str]]:
        """
        A list of port IDs that are associated with the BGP VPN.
        """
        return pulumi.get(self, "ports")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID of the project that owns the BGPVPN. Only
        administrative and users with `advsvc` role can specify a project ID other
        than their own. Changing this creates a new BGP VPN.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def region(self) -> pulumi.Output[_builtins.str]:
        """
        The region in which to obtain the V2 Networking client.
        A Networking client is needed to create a BGP VPN service. If omitted, the
        `region` argument of the provider is used. Changing this creates a new
        BGP VPN.
        """
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter(name="routeDistinguishers")
    def route_distinguishers(self) -> pulumi.Output[Sequence[_builtins.str]]:
        """
        A list of route distinguisher strings. If
        specified, one of these RDs will be used to advertise VPN routes.
        """
        return pulumi.get(self, "route_distinguishers")

    @_builtins.property
    @pulumi.getter(name="routeTargets")
    def route_targets(self) -> pulumi.Output[Sequence[_builtins.str]]:
        """
        A list of Route Targets that will be both
        imported and used for export.
        """
        return pulumi.get(self, "route_targets")

    @_builtins.property
    @pulumi.getter
    def routers(self) -> pulumi.Output[Sequence[_builtins.str]]:
        """
        A list of router IDs that are associated with the BGP VPN.
        """
        return pulumi.get(self, "routers")

    @_builtins.property
    @pulumi.getter
    def shared(self) -> pulumi.Output[_builtins.bool]:
        """
        Indicates whether the BGP VPN is shared across projects.
        """
        return pulumi.get(self, "shared")

    @_builtins.property
    @pulumi.getter
    def type(self) -> pulumi.Output[_builtins.str]:
        """
        The type of the BGP VPN (either `l2` or `l3`). Changing this
        creates a new BGP VPN. Defaults to `l3`.
        """
        return pulumi.get(self, "type")

    @_builtins.property
    @pulumi.getter
    def vni(self) -> pulumi.Output[Optional[_builtins.int]]:
        """
        The globally-assigned VXLAN VNI for the BGP VPN. Changing
        this creates a new BGP VPN.
        """
        return pulumi.get(self, "vni")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['ShareNetworkArgs', 'ShareNetwork']

@pulumi.input_type
class ShareNetworkArgs:
    def __init__(__self__, *,
                 neutron_net_id: pulumi.Input[_builtins.str],
                 neutron_subnet_id: pulumi.Input[_builtins.str],
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 security_service_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None):
        """
        The set of arguments for constructing a ShareNetwork resource.
        :param pulumi.Input[_builtins.str] neutron_net_id: The UUID of a neutron network when setting up or updating
               a share network. Changing this updates the existing share network if it's not used by
               shares.
        :param pulumi.Input[_builtins.str] neutron_subnet_id: The UUID of the neutron subnet when setting up or
               updating a share network. Changing this updates the existing share network if it's
               not used by shares.
        :param pulumi.Input[_builtins.str] description: The human-readable description for the share network.
               Changing this updates the description of the existing share network.
        :param pulumi.Input[_builtins.str] name: The name for the share network. Changing this updates the name
               of the existing share network.
        :param pulumi.Input[_builtins.str] region: The region in which to obtain the V2 Shared File System client.
               A Shared File System client is needed to create a share network. If omitted, the
               `region` argument of the provider is used. Changing this creates a new
               share network.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] security_service_ids: The list of security service IDs to associate with
               the share network. The security service must be specified by ID and not name.
        """
        pulumi.set(__self__, "neutron_net_id", neutron_net_id)
        pulumi.set(__self__, "neutron_subnet_id", neutron_subnet_id)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if security_service_ids is not None:
            pulumi.set(__self__, "security_service_ids", security_service_ids)

    @_builtins.property
    @pulumi.getter(name="neutronNetId")
    def neutron_net_id(self) -> pulumi.Input[_builtins.str]:
        """
        The UUID of a neutron network when setting up or updating
        a share network. Changing this updates the existing share network if it's not used by
        shares.
        """
        return pulumi.get(self, "neutron_net_id")

    @neutron_net_id.setter
    def neutron_net_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "neutron_net_id", value)

    @_builtins.property
    @pulumi.getter(name="neutronSubnetId")
    def neutron_subnet_id(self) -> pulumi.Input[_builtins.str]:
        """
        The UUID of the neutron subnet when setting up or
        updating a share network. Changing this updates the existing share network if it's
        not used by shares.
        """
        return pulumi.get(self, "neutron_subnet_id")

    @neutron_subnet_id.setter
    def neutron_subnet_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "neutron_subnet_id", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The human-readable description for the share network.
        Changing this updates the description of the existing share network.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name for the share network. Changing this updates the name
        of the existing share network.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The region in which to obtain the V2 Shared File System client.
        A Shared File System client is needed to create a share network. If omitted, the
        `region` argument of the provider is used. Changing this creates a new
        share network.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter(name="securityServiceIds")
    def security_service_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        The list of security service IDs to associate with
        the share network. The security service must be specified by ID and not name.
        """
        return pulumi.get(self, "security_service_ids")

    @security_service_ids.setter
    def security_service_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "security_service_ids", value)


@pulumi.input_type
class _ShareNetworkState:
    def __init__(__self__, *,
                 cidr: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 ip_version: Optional[pulumi.Input[_builtins.int]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 network_type: Optional[pulumi.Input[_builtins.str]] = None,
                 neutron_net_id: Optional[pulumi.Input[_builtins.str]] = None,
                 neutron_subnet_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 security_service_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 segmentation_id: Optional[pulumi.Input[_builtins.int]] = None):
        """
        Input properties used for looking up and filtering ShareNetwork resources.
        :param pulumi.Input[_builtins.str] cidr: The share network CIDR.
        :param pulumi.Input[_builtins.str] description: The human-readable description for the share network.
               Changing this updates the description of the existing share network.
        :param pulumi.Input[_builtins.int] ip_version: The IP version of the share network. Can either be 4 or 6.
        :param pulumi.Input[_builtins.str] name: The name for the share network. Changing this updates the name
               of the existing share network.
        :param pulumi.Input[_builtins.str] network_type: The share network type. Can either be VLAN, VXLAN, GRE, or flat.
        :param pulumi.Input[_builtins.str] neutron_net_id: The UUID of a neutron network when setting up or updating
               a share network. Changing this updates the existing share network if it's not used by
               shares.
        :param pulumi.Input[_builtins.str] neutron_subnet_id: The UUID of the neutron subnet when setting up or
               updating a share network. Changing this updates the existing share network if it's
               not used by shares.
        :param pulumi.Input[_builtins.str] project_id: The owner of the Share Network.
        :param pulumi.Input[_builtins.str] region: The region in which to obtain the V2 Shared File System client.
               A Shared File System client is needed to create a share network. If omitted, the
               `region` argument of the provider is used. Changing this creates a new
               share network.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] security_service_ids: The list of security service IDs to associate with
               the share network. The security service must be specified by ID and not name.
        :param pulumi.Input[_builtins.int] segmentation_id: The share network segmentation ID.
        """
        if cidr is not None:
            pulumi.set(__self__, "cidr", cidr)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if ip_version is not None:
            pulumi.set(__self__, "ip_version", ip_version)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if network_type is not None:
            pulumi.set(__self__, "network_type", network_type)
        if neutron_net_id is not None:
            pulumi.set(__self__, "neutron_net_id", neutron_net_id)
        if neutron_subnet_id is not None:
            pulumi.set(__self__, "neutron_subnet_id", neutron_subnet_id)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if security_service_ids is not None:
            pulumi.set(__self__, "security_service_ids", security_service_ids)
        if segmentation_id is not None:
            pulumi.set(__self__, "segmentation_id", segmentation_id)

    @_builtins.property
    @pulumi.getter
    def cidr(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The share network CIDR.
        """
        return pulumi.get(self, "cidr")

    @cidr.setter
    def cidr(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "cidr", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The human-readable description for the share network.
        Changing this updates the description of the existing share network.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="ipVersion")
    def ip_version(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The IP version of the share network. Can either be 4 or 6.
        """
        return pulumi.get(self, "ip_version")

    @ip_version.setter
    def ip_version(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "ip_version", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name for the share network. Changing this updates the name
        of the existing share network.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="networkType")
    def network_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The share network type. Can either be VLAN, VXLAN, GRE, or flat.
        """
        return pulumi.get(self, "network_type")

    @network_type.setter
    def network_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "network_type", value)

    @_builtins.property
    @pulumi.getter(name="neutronNetId")
    def neutron_net_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The UUID of a neutron network when setting up or updating
        a share network. Changing this updates the existing share network if it's not used by
        shares.
        """
        return pulumi.get(self, "neutron_net_id")

    @neutron_net_id.setter
    def neutron_net_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "neutron_net_id", value)

    @_builtins.property
    @pulumi.getter(name="neutronSubnetId")
    def neutron_subnet_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The UUID of the neutron subnet when setting up or
        updating a share network. Changing this updates the existing share network if it's
        not used by shares.
        """
        return pulumi.get(self, "neutron_subnet_id")

    @neutron_subnet_id.setter
    def neutron_subnet_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "neutron_subnet_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The owner of the Share Network.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The region in which to obtain the V2 Shared File System client.
        A Shared File System client is needed to create a share network. If omitted, the
        `region` argument of the provider is used. Changing this creates a new
        share network.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter(name="securityServiceIds")
    def security_service_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        The list of security service IDs to associate with
        the share network. The security service must be specified by ID and not name.
        """
        return pulumi.get(self, "security_service_ids")

    @security_service_ids.setter
    def security_service_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "security_service_ids", value)

    @_builtins.property
    @pulumi.getter(name="segmentationId")
    def segmentation_id(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The share network segmentation ID.
        """
        return pulumi.get(self, "segmentation_id")

    @segmentation_id.setter
    def segmentation_id(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "segmentation_id", value)


@pulumi.type_token("openstack:sharedfilesystem/shareNetwork:ShareNetwork")
class ShareNetwork(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 neutron_net_id: Optional[pulumi.Input[_builtins.str]] = None,
                 neutron_subnet_id: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 security_service_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        """
        Use this resource to configure a share network.

        A share network stores network information that share servers can use when
        shares are created.

        ## Example Usage

        ### Basic share network

        ```python
        import pulumi
        import pulumi_openstack as openstack

        network1 = openstack.networking.Network("network_1",
            name="network_1",
            admin_state_up=True)
        subnet1 = openstack.networking.Subnet("subnet_1",
            name="subnet_1",
            cidr="192.168.199.0/24",
            ip_version=4,
            network_id=network1.id)
        sharenetwork1 = openstack.sharedfilesystem.ShareNetwork("sharenetwork_1",
            name="test_sharenetwork",
            description="test share network",
            neutron_net_id=network1.id,
            neutron_subnet_id=subnet1.id)
        ```

        ### Share network with associated security services

        ```python
        import pulumi
        import pulumi_openstack as openstack

        network1 = openstack.networking.Network("network_1",
            name="network_1",
            admin_state_up=True)
        subnet1 = openstack.networking.Subnet("subnet_1",
            name="subnet_1",
            cidr="192.168.199.0/24",
            ip_version=4,
            network_id=network1.id)
        securityservice1 = openstack.sharedfilesystem.SecurityService("securityservice_1",
            name="security",
            description="created by terraform",
            type="active_directory",
            server="192.168.199.10",
            dns_ip="192.168.199.10",
            domain="example.com",
            ou="CN=Computers,DC=example,DC=com",
            user="joinDomainUser",
            password="s8cret")
        sharenetwork1 = openstack.sharedfilesystem.ShareNetwork("sharenetwork_1",
            name="test_sharenetwork",
            description="test share network with security services",
            neutron_net_id=network1.id,
            neutron_subnet_id=subnet1.id,
            security_service_ids=[securityservice1.id])
        ```

        ## Import

        This resource can be imported by specifying the ID of the share network:

        ```sh
        $ pulumi import openstack:sharedfilesystem/shareNetwork:ShareNetwork sharenetwork_1 id
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] description: The human-readable description for the share network.
               Changing this updates the description of the existing share network.
        :param pulumi.Input[_builtins.str] name: The name for the share network. Changing this updates the name
               of the existing share network.
        :param pulumi.Input[_builtins.str] neutron_net_id: The UUID of a neutron network when setting up or updating
               a share network. Changing this updates the existing share network if it's not used by
               shares.
        :param pulumi.Input[_builtins.str] neutron_subnet_id: The UUID of the neutron subnet when setting up or
               updating a share network. Changing this updates the existing share network if it's
               not used by shares.
        :param pulumi.Input[_builtins.str] region: The region in which to obtain the V2 Shared File System client.
               A Shared File System client is needed to create a share network. If omitted, the
               `region` argument of the provider is used. Changing this creates a new
               share network.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] security_service_ids: The list of security service IDs to associate with
               the share network. The security service must be specified by ID and not name.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ShareNetworkArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Use this resource to configure a share network.

        A share network stores network information that share servers can use when
        shares are created.

        ## Example Usage

        ### Basic share network

        ```python
        import pulumi
        import pulumi_openstack as openstack

        network1 = openstack.networking.Network("network_1",
            name="network_1",
            admin_state_up=True)
        subnet1 = openstack.networking.Subnet("subnet_1",
            name="subnet_1",
            cidr="192.168.199.0/24",
            ip_version=4,
            network_id=network1.id)
        sharenetwork1 = openstack.sharedfilesystem.ShareNetwork("sharenetwork_1",
            name="test_sharenetwork",
            description="test share network",
            neutron_net_id=network1.id,
            neutron_subnet_id=subnet1.id)
        ```

        ### Share network with associated security services

        ```python
        import pulumi
        import pulumi_openstack as openstack

        network1 = openstack.networking.Network("network_1",
            name="network_1",
            admin_state_up=True)
        subnet1 = openstack.networking.Subnet("subnet_1",
            name="subnet_1",
            cidr="192.168.199.0/24",
            ip_version=4,
            network_id=network1.id)
        securityservice1 = openstack.sharedfilesystem.SecurityService("securityservice_1",
            name="security",
            description="created by terraform",
            type="active_directory",
            server="192.168.199.10",
            dns_ip="192.168.199.10",
            domain="example.com",
            ou="CN=Computers,DC=example,DC=com",
            user="joinDomainUser",
            password="s8cret")
        sharenetwork1 = openstack.sharedfilesystem.ShareNetwork("sharenetwork_1",
            name="test_sharenetwork",
            description="test share network with security services",
            neutron_net_id=network1.id,
            neutron_subnet_id=subnet1.id,
            security_service_ids=[securityservice1.id])
        ```

        ## Import

        This resource can be imported by specifying the ID of the share network:

        ```sh
        $ pulumi import openstack:sharedfilesystem/shareNetwork:ShareNetwork sharenetwork_1 id
        ```

        :param str resource_name: The name of the resource.
        :param ShareNetworkArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ShareNetworkArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 neutron_net_id: Optional[pulumi.Input[_builtins.str]] = None,
                 neutron_subnet_id: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 security_service_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ShareNetworkArgs.__new__(ShareNetworkArgs)

            __props__.__dict__["description"] = description
            __props__.__dict__["name"] = name
            if neutron_net_id is None and not opts.urn:
                raise TypeError("Missing required property 'neutron_net_id'")
            __props__.__dict__["neutron_net_id"] = neutron_net_id
            if neutron_subnet_id is None and not opts.urn:
                raise TypeError("Missing required property 'neutron_subnet_id'")
            __props__.__dict__["neutron_subnet_id"] = neutron_subnet_id
            __props__.__dict__["region"] = region
            __props__.__dict__["security_service_ids"] = security_service_ids
            __props__.__dict__["cidr"] = None
            __props__.__dict__["ip_version"] = None
            __props__.__dict__["network_type"] = None
            __props__.__dict__["project_id"] = None
            __props__.__dict__["segmentation_id"] = None
        super(ShareNetwork, __self__).__init__(
            'openstack:sharedfilesystem/shareNetwork:ShareNetwork',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            cidr: Optional[pulumi.Input[_builtins.str]] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            ip_version: Optional[pulumi.Input[_builtins.int]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            network_type: Optional[pulumi.Input[_builtins.str]] = None,
            neutron_net_id: Optional[pulumi.Input[_builtins.str]] = None,
            neutron_subnet_id: Optional[pulumi.Input[_builtins.str]] = None,
            project_id: Optional[pulumi.Input[_builtins.str]] = None,
            region: Optional[pulumi.Input[_builtins.str]] = None,
            security_service_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            segmentation_id: Optional[pulumi.Input[_builtins.int]] = None) -> 'ShareNetwork':
        """
        Get an existing ShareNetwork resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] cidr: The share network CIDR.
        :param pulumi.Input[_builtins.str] description: The human-readable description for the share network.
               Changing this updates the description of the existing share network.
        :param pulumi.Input[_builtins.int] ip_version: The IP version of the share network. Can either be 4 or 6.
        :param pulumi.Input[_builtins.str] name: The name for the share network. Changing this updates the name
               of the existing share network.
        :param pulumi.Input[_builtins.str] network_type: The share network type. Can either be VLAN, VXLAN, GRE, or flat.
        :param pulumi.Input[_builtins.str] neutron_net_id: The UUID of a neutron network when setting up or updating
               a share network. Changing this updates the existing share network if it's not used by
               shares.
        :param pulumi.Input[_builtins.str] neutron_subnet_id: The UUID of the neutron subnet when setting up or
               updating a share network. Changing this updates the existing share network if it's
               not used by shares.
        :param pulumi.Input[_builtins.str] project_id: The owner of the Share Network.
        :param pulumi.Input[_builtins.str] region: The region in which to obtain the V2 Shared File System client.
               A Shared File System client is needed to create a share network. If omitted, the
               `region` argument of the provider is used. Changing this creates a new
               share network.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] security_service_ids: The list of security service IDs to associate with
               the share network. The security service must be specified by ID and not name.
        :param pulumi.Input[_builtins.int] segmentation_id: The share network segmentation ID.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ShareNetworkState.__new__(_ShareNetworkState)

        __props__.__dict__["cidr"] = cidr
        __props__.__dict__["description"] = description
        __props__.__dict__["ip_version"] = ip_version
        __props__.__dict__["name"] = name
        __props__.__dict__["network_type"] = network_type
        __props__.__dict__["neutron_net_id"] = neutron_net_id
        __props__.__dict__["neutron_subnet_id"] = neutron_subnet_id
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["region"] = region
        __props__.__dict__["security_service_ids"] = security_service_ids
        __props__.__dict__["segmentation_id"] = segmentation_id
        return ShareNetwork(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def cidr(self) -> pulumi.Output[_builtins.str]:
        """
        The share network CIDR.
        """
        return pulumi.get(self, "cidr")

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The human-readable description for the share network.
        Changing this updates the description of the existing share network.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="ipVersion")
    def ip_version(self) -> pulumi.Output[_builtins.int]:
        """
        The IP version of the share network. Can either be 4 or 6.
        """
        return pulumi.get(self, "ip_version")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The name for the share network. Changing this updates the name
        of the existing share network.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="networkType")
    def network_type(self) -> pulumi.Output[_builtins.str]:
        """
        The share network type. Can either be VLAN, VXLAN, GRE, or flat.
        """
        return pulumi.get(self, "network_type")

    @_builtins.property
    @pulumi.getter(name="neutronNetId")
    def neutron_net_id(self) -> pulumi.Output[_builtins.str]:
        """
        The UUID of a neutron network when setting up or updating
        a share network. Changing this updates the existing share network if it's not used by
        shares.
        """
        return pulumi.get(self, "neutron_net_id")

    @_builtins.property
    @pulumi.getter(name="neutronSubnetId")
    def neutron_subnet_id(self) -> pulumi.Output[_builtins.str]:
        """
        The UUID of the neutron subnet when setting up or
        updating a share network. Changing this updates the existing share network if it's
        not used by shares.
        """
        return pulumi.get(self, "neutron_subnet_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[_builtins.str]:
        """
        The owner of the Share Network.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def region(self) -> pulumi.Output[_builtins.str]:
        """
        The region in which to obtain the V2 Shared File System client.
        A Shared File System client is needed to create a share network. If omitted, the
        `region` argument of the provider is used. Changing this creates a new
        share network.
        """
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter(name="securityServiceIds")
    def security_service_ids(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        The list of security service IDs to associate with
        the share network. The security service must be specified by ID and not name.
        """
        return pulumi.get(self, "security_service_ids")

    @_builtins.property
    @pulumi.getter(name="segmentationId")
    def segmentation_id(self) -> pulumi.Output[_builtins.int]:
        """
        The share network segmentation ID.
        """
        return pulumi.get(self, "segmentation_id")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['ProjectArgs', 'Project']

@pulumi.input_type
class ProjectArgs:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 domain_id: Optional[pulumi.Input[_builtins.str]] = None,
                 enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 is_domain: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 parent_id: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None):
        """
        The set of arguments for constructing a Project resource.
        :param pulumi.Input[_builtins.str] description: A description of the project.
        :param pulumi.Input[_builtins.str] domain_id: The domain this project belongs to.
        :param pulumi.Input[_builtins.bool] enabled: Whether the project is enabled or disabled. Valid
               values are `true` and `false`. Default is `true`.
        :param pulumi.Input[_builtins.bool] is_domain: Whether this project is a domain. Valid values
               are `true` and `false`. Default is `false`. Changing this creates a new
               project/domain.
        :param pulumi.Input[_builtins.str] name: The name of the project.
        :param pulumi.Input[_builtins.str] parent_id: The parent of this project. Changing this creates
               a new project.
        :param pulumi.Input[_builtins.str] region: The region in which to obtain the V3 Keystone client.
               If omitted, the `region` argument of the provider is used. Changing this
               creates a new project.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags for the project. Changing this updates the existing
               project.
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if domain_id is not None:
            pulumi.set(__self__, "domain_id", domain_id)
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)
        if is_domain is not None:
            pulumi.set(__self__, "is_domain", is_domain)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if parent_id is not None:
            pulumi.set(__self__, "parent_id", parent_id)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        A description of the project.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="domainId")
    def domain_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The domain this project belongs to.
        """
        return pulumi.get(self, "domain_id")

    @domain_id.setter
    def domain_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "domain_id", value)

    @_builtins.property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether the project is enabled or disabled. Valid
        values are `true` and `false`. Default is `true`.
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "enabled", value)

    @_builtins.property
    @pulumi.getter(name="isDomain")
    def is_domain(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether this project is a domain. Valid values
        are `true` and `false`. Default is `false`. Changing this creates a new
        project/domain.
        """
        return pulumi.get(self, "is_domain")

    @is_domain.setter
    def is_domain(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "is_domain", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the project.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="parentId")
    def parent_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The parent of this project. Changing this creates
        a new project.
        """
        return pulumi.get(self, "parent_id")

    @parent_id.setter
    def parent_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "parent_id", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The region in which to obtain the V3 Keystone client.
        If omitted, the `region` argument of the provider is used. Changing this
        creates a new project.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Tags for the project. Changing this updates the existing
        project.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _ProjectState:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 domain_id: Optional[pulumi.Input[_builtins.str]] = None,
                 enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 is_domain: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 parent_id: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None):
        """
        Input properties used for looking up and filtering Project resources.
        :param pulumi.Input[_builtins.str] description: A description of the project.
        :param pulumi.Input[_builtins.str] domain_id: The domain this project belongs to.
        :param pulumi.Input[_builtins.bool] enabled: Whether the project is enabled or disabled. Valid
               values are `true` and `false`. Default is `true`.
        :param pulumi.Input[_builtins.bool] is_domain: Whether this project is a domain. Valid values
               are `true` and `false`. Default is `false`. Changing this creates a new
               project/domain.
        :param pulumi.Input[_builtins.str] name: The name of the project.
        :param pulumi.Input[_builtins.str] parent_id: The parent of this project. Changing this creates
               a new project.
        :param pulumi.Input[_builtins.str] region: The region in which to obtain the V3 Keystone client.
               If omitted, the `region` argument of the provider is used. Changing this
               creates a new project.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags for the project. Changing this updates the existing
               project.
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if domain_id is not None:
            pulumi.set(__self__, "domain_id", domain_id)
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)
        if is_domain is not None:
            pulumi.set(__self__, "is_domain", is_domain)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if parent_id is not None:
            pulumi.set(__self__, "parent_id", parent_id)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        A description of the project.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="domainId")
    def domain_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The domain this project belongs to.
        """
        return pulumi.get(self, "domain_id")

    @domain_id.setter
    def domain_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "domain_id", value)

    @_builtins.property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether the project is enabled or disabled. Valid
        values are `true` and `false`. Default is `true`.
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "enabled", value)

    @_builtins.property
    @pulumi.getter(name="isDomain")
    def is_domain(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether this project is a domain. Valid values
        are `true` and `false`. Default is `false`. Changing this creates a new
        project/domain.
        """
        return pulumi.get(self, "is_domain")

    @is_domain.setter
    def is_domain(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "is_domain", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the project.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="parentId")
    def parent_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The parent of this project. Changing this creates
        a new project.
        """
        return pulumi.get(self, "parent_id")

    @parent_id.setter
    def parent_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "parent_id", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The region in which to obtain the V3 Keystone client.
        If omitted, the `region` argument of the provider is used. Changing this
        creates a new project.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Tags for the project. Changing this updates the existing
        project.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)


@pulumi.type_token("openstack:identity/project:Project")
class Project(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 domain_id: Optional[pulumi.Input[_builtins.str]] = None,
                 enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 is_domain: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 parent_id: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        """
        Manages a V3 Project resource within OpenStack Keystone.

        > **Note:** You _must_ have admin privileges in your OpenStack cloud to use
        this resource.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_openstack as openstack

        project1 = openstack.identity.Project("project_1",
            name="project_1",
            description="A project")
        ```

        ## Import

        Projects can be imported using the `id`, e.g.

        ```sh
        $ pulumi import openstack:identity/project:Project project_1 89c60255-9bd6-460c-822a-e2b959ede9d2
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] description: A description of the project.
        :param pulumi.Input[_builtins.str] domain_id: The domain this project belongs to.
        :param pulumi.Input[_builtins.bool] enabled: Whether the project is enabled or disabled. Valid
               values are `true` and `false`. Default is `true`.
        :param pulumi.Input[_builtins.bool] is_domain: Whether this project is a domain. Valid values
               are `true` and `false`. Default is `false`. Changing this creates a new
               project/domain.
        :param pulumi.Input[_builtins.str] name: The name of the project.
        :param pulumi.Input[_builtins.str] parent_id: The parent of this project. Changing this creates
               a new project.
        :param pulumi.Input[_builtins.str] region: The region in which to obtain the V3 Keystone client.
               If omitted, the `region` argument of the provider is used. Changing this
               creates a new project.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags for the project. Changing this updates the existing
               project.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[ProjectArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages a V3 Project resource within OpenStack Keystone.

        > **Note:** You _must_ have admin privileges in your OpenStack cloud to use
        this resource.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_openstack as openstack

        project1 = openstack.identity.Project("project_1",
            name="project_1",
            description="A project")
        ```

        ## Import

        Projects can be imported using the `id`, e.g.

        ```sh
        $ pulumi import openstack:identity/project:Project project_1 89c60255-9bd6-460c-822a-e2b959ede9d2
        ```

        :param str resource_name: The name of the resource.
        :param ProjectArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ProjectArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 domain_id: Optional[pulumi.Input[_builtins.str]] = None,
                 enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 is_domain: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 parent_id: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ProjectArgs.__new__(ProjectArgs)

            __props__.__dict__["description"] = description
            __props__.__dict__["domain_id"] = domain_id
            __props__.__dict__["enabled"] = enabled
            __props__.__dict__["is_domain"] = is_domain
            __props__.__dict__["name"] = name
            __props__.__dict__["parent_id"] = parent_id
            __props__.__dict__["region"] = region
            __props__.__dict__["tags"] = tags
        super(Project, __self__).__init__(
            'openstack:identity/project:Project',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            domain_id: Optional[pulumi.Input[_builtins.str]] = None,
            enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            is_domain: Optional[pulumi.Input[_builtins.bool]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            parent_id: Optional[pulumi.Input[_builtins.str]] = None,
            region: Optional[pulumi.Input[_builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None) -> 'Project':
        """
        Get an existing Project resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] description: A description of the project.
        :param pulumi.Input[_builtins.str] domain_id: The domain this project belongs to.
        :param pulumi.Input[_builtins.bool] enabled: Whether the project is enabled or disabled. Valid
               values are `true` and `false`. Default is `true`.
        :param pulumi.Input[_builtins.bool] is_domain: Whether this project is a domain. Valid values
               are `true` and `false`. Default is `false`. Changing this creates a new
               project/domain.
        :param pulumi.Input[_builtins.str] name: The name of the project.
        :param pulumi.Input[_builtins.str] parent_id: The parent of this project. Changing this creates
               a new project.
        :param pulumi.Input[_builtins.str] region: The region in which to obtain the V3 Keystone client.
               If omitted, the `region` argument of the provider is used. Changing this
               creates a new project.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags for the project. Changing this updates the existing
               project.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ProjectState.__new__(_ProjectState)

        __props__.__dict__["description"] = description
        __props__.__dict__["domain_id"] = domain_id
        __props__.__dict__["enabled"] = enabled
        __props__.__dict__["is_domain"] = is_domain
        __props__.__dict__["name"] = name
        __props__.__dict__["parent_id"] = parent_id
        __props__.__dict__["region"] = region
        __props__.__dict__["tags"] = tags
        return Project(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        A description of the project.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="domainId")
    def domain_id(self) -> pulumi.Output[_builtins.str]:
        """
        The domain this project belongs to.
        """
        return pulumi.get(self, "domain_id")

    @_builtins.property
    @pulumi.getter
    def enabled(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Whether the project is enabled or disabled. Valid
        values are `true` and `false`. Default is `true`.
        """
        return pulumi.get(self, "enabled")

    @_builtins.property
    @pulumi.getter(name="isDomain")
    def is_domain(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Whether this project is a domain. Valid values
        are `true` and `false`. Default is `false`. Changing this creates a new
        project/domain.
        """
        return pulumi.get(self, "is_domain")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the project.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="parentId")
    def parent_id(self) -> pulumi.Output[_builtins.str]:
        """
        The parent of this project. Changing this creates
        a new project.
        """
        return pulumi.get(self, "parent_id")

    @_builtins.property
    @pulumi.getter
    def region(self) -> pulumi.Output[_builtins.str]:
        """
        The region in which to obtain the V3 Keystone client.
        If omitted, the `region` argument of the provider is used. Changing this
        creates a new project.
        """
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        Tags for the project. Changing this updates the existing
        project.
        """
        return pulumi.get(self, "tags")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'BgpvpnPortAssociateV2Route',
    'TaasTapMirrorV2Directions',
]

@pulumi.output_type
class BgpvpnPortAssociateV2Route(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "bgpvpnId":
            suggest = "bgpvpn_id"
        elif key == "localPref":
            suggest = "local_pref"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in BgpvpnPortAssociateV2Route. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        BgpvpnPortAssociateV2Route.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        BgpvpnPortAssociateV2Route.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 type: _builtins.str,
                 bgpvpn_id: Optional[_builtins.str] = None,
                 local_pref: Optional[_builtins.int] = None,
                 prefix: Optional[_builtins.str] = None):
        """
        :param _builtins.str type: Can be `prefix` or `bgpvpn`. For the `prefix` type, the
               CIDR prefix (v4 or v6) must be specified in the `prefix` key. For the
               `bgpvpn` type, the BGP VPN ID must be specified in the `bgpvpn_id` key.
        :param _builtins.str bgpvpn_id: The ID of the BGP VPN to be advertised. Required
               if `type` is `bgpvpn`. Conflicts with `prefix`.
        :param _builtins.int local_pref: The BGP LOCAL\\_PREF value of the routes that will
               be advertised.
        :param _builtins.str prefix: The CIDR prefix (v4 or v6) to be advertised. Required
               if `type` is `prefix`. Conflicts with `bgpvpn_id`.
        """
        pulumi.set(__self__, "type", type)
        if bgpvpn_id is not None:
            pulumi.set(__self__, "bgpvpn_id", bgpvpn_id)
        if local_pref is not None:
            pulumi.set(__self__, "local_pref", local_pref)
        if prefix is not None:
            pulumi.set(__self__, "prefix", prefix)

    @_builtins.property
    @pulumi.getter
    def type(self) -> _builtins.str:
        """
        Can be `prefix` or `bgpvpn`. For the `prefix` type, the
        CIDR prefix (v4 or v6) must be specified in the `prefix` key. For the
        `bgpvpn` type, the BGP VPN ID must be specified in the `bgpvpn_id` key.
        """
        return pulumi.get(self, "type")

    @_builtins.property
    @pulumi.getter(name="bgpvpnId")
    def bgpvpn_id(self) -> Optional[_builtins.str]:
        """
        The ID of the BGP VPN to be advertised. Required
        if `type` is `bgpvpn`. Conflicts with `prefix`.
        """
        return pulumi.get(self, "bgpvpn_id")

    @_builtins.property
    @pulumi.getter(name="localPref")
    def local_pref(self) -> Optional[_builtins.int]:
        """
        The BGP LOCAL\\_PREF value of the routes that will
        be advertised.
        """
        return pulumi.get(self, "local_pref")

    @_builtins.property
    @pulumi.getter
    def prefix(self) -> Optional[_builtins.str]:
        """
        The CIDR prefix (v4 or v6) to be advertised. Required
        if `type` is `prefix`. Conflicts with `bgpvpn_id`.
        """
        return pulumi.get(self, "prefix")


@pulumi.output_type
class TaasTapMirrorV2Directions(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "in":
            suggest = "in_"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in TaasTapMirrorV2Directions. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        TaasTapMirrorV2Directions.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        TaasTapMirrorV2Directions.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 in_: Optional[_builtins.int] = None,
                 out: Optional[_builtins.int] = None):
        """
        :param _builtins.int in_: Declares ingress traffic to the port will be mirrored. The value
               is the identifier of the ERSPAN or GRE session between the source and destination,
               this must be unique within the project.
        :param _builtins.int out: Declares egress traffic will be mirrored. The value is the
               identifier of the ERSPAN or GRE session between the source and destination,
               this must be unique within the project.
        """
        if in_ is not None:
            pulumi.set(__self__, "in_", in_)
        if out is not None:
            pulumi.set(__self__, "out", out)

    @_builtins.property
    @pulumi.getter(name="in")
    def in_(self) -> Optional[_builtins.int]:
        """
        Declares ingress traffic to the port will be mirrored. The value
        is the identifier of the ERSPAN or GRE session between the source and destination,
        this must be unique within the project.
        """
        return pulumi.get(self, "in_")

    @_builtins.property
    @pulumi.getter
    def out(self) -> Optional[_builtins.int]:
        """
        Declares egress traffic will be mirrored. The value is the
        identifier of the ERSPAN or GRE session between the source and destination,
        this must be unique within the project.
        """
        return pulumi.get(self, "out")


